==> haskell-postgresql-simple-0.6.5.1-20.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgresql-simple
version:              0.6.5.1
visibility:           public
id:                   postgresql-simple-0.6.5.1-KFldKXMxD9BGDXIxmiNG6b
key:                  postgresql-simple-0.6.5.1-KFldKXMxD9BGDXIxmiNG6b
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.
    (c) 2011-2018 Leon P Smith
    (c) 2018-2020 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Bryan O'\''Sullivan, Leon P Smith
synopsis:             Mid-Level PostgreSQL client library
description:
    Mid-Level PostgreSQL client library, forked from mysql-simple.

category:             Database
abi:                  82b1ba94d935620f5aebb64b4a4144f4
exposed:              True
exposed-modules:
    Database.PostgreSQL.Simple Database.PostgreSQL.Simple.Arrays
    Database.PostgreSQL.Simple.Copy Database.PostgreSQL.Simple.Cursor
    Database.PostgreSQL.Simple.Errors
    Database.PostgreSQL.Simple.FromField
    Database.PostgreSQL.Simple.FromRow
    Database.PostgreSQL.Simple.HStore
    Database.PostgreSQL.Simple.HStore.Internal
    Database.PostgreSQL.Simple.Internal
    Database.PostgreSQL.Simple.LargeObjects
    Database.PostgreSQL.Simple.Newtypes
    Database.PostgreSQL.Simple.Notification
    Database.PostgreSQL.Simple.Ok Database.PostgreSQL.Simple.Range
    Database.PostgreSQL.Simple.SqlQQ Database.PostgreSQL.Simple.Time
    Database.PostgreSQL.Simple.Time.Internal
    Database.PostgreSQL.Simple.ToField Database.PostgreSQL.Simple.ToRow
    Database.PostgreSQL.Simple.Transaction
    Database.PostgreSQL.Simple.TypeInfo
    Database.PostgreSQL.Simple.TypeInfo.Macro
    Database.PostgreSQL.Simple.TypeInfo.Static
    Database.PostgreSQL.Simple.Types Database.PostgreSQL.Simple.Vector
    Database.PostgreSQL.Simple.Vector.Unboxed

hidden-modules:
    Database.PostgreSQL.Simple.Compat
    Database.PostgreSQL.Simple.HStore.Implementation
    Database.PostgreSQL.Simple.Internal.PQResultUtils
    Database.PostgreSQL.Simple.Time.Implementation
    Database.PostgreSQL.Simple.Time.Internal.Parser
    Database.PostgreSQL.Simple.Time.Internal.Printer
    Database.PostgreSQL.Simple.TypeInfo.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/postgresql-simple-0.6.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/postgresql-simple-0.6.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/postgresql-simple-0.6.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-postgresql-simple
hs-libraries:         HSpostgresql-simple-0.6.5.1-KFldKXMxD9BGDXIxmiNG6b
depends:
    Only-0.1-2ALIOaFTuVl17VyQ33BnR1
    aeson-2.1.2.1-38LADbNStwmEfKOReucTQy
    attoparsec-0.14.4-K9rgVNreKMkFhZdMbsqsTo base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-ADYWB5NR7iSCpUfBs08sXI
    containers-0.6.7 hashable-1.4.4.0-AT2Ub72SgpTFIbLYNtgVpj
    postgresql-libpq-0.9.4.3-9EKBGqszgJV2gOXf0kEzu1
    scientific-0.3.7.0-FVWP8DVCKbGBwiSARe0xui template-haskell-2.19.0.0
    text-2.0.2 time-compat-1.9.6.1-5KZ68IGiHEY1RFgTZ9UydC
    transformers-0.5.6.2 uuid-types-1.0.6-BroLMqqyDfqHfqENK4I1Bq
    vector-0.13.2.0-H3MTIE0bxkOEYwCD854O16

haddock-interfaces:
    /usr/share/doc/haskell-postgresql-simple/html/postgresql-simple.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-simple-0.6.5-69-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 postgresql-simple
version:              0.6.5
visibility:           public
id:                   postgresql-simple-0.6.5-1bJK5KSvjQ6FaX8TDJVqT3
key:                  postgresql-simple-0.6.5-1bJK5KSvjQ6FaX8TDJVqT3
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.
    (c) 2011-2018 Leon P Smith
    (c) 2018-2020 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Bryan O'\''Sullivan, Leon P Smith
synopsis:             Mid-Level PostgreSQL client library
description:
    Mid-Level PostgreSQL client library, forked from mysql-simple.

category:             Database
abi:                  41a760bd3fc5905b66034c701d801403
exposed:              True
exposed-modules:
    Database.PostgreSQL.Simple Database.PostgreSQL.Simple.Arrays
    Database.PostgreSQL.Simple.Copy Database.PostgreSQL.Simple.Cursor
    Database.PostgreSQL.Simple.Errors
    Database.PostgreSQL.Simple.FromField
    Database.PostgreSQL.Simple.FromRow
    Database.PostgreSQL.Simple.HStore
    Database.PostgreSQL.Simple.HStore.Internal
    Database.PostgreSQL.Simple.Internal
    Database.PostgreSQL.Simple.LargeObjects
    Database.PostgreSQL.Simple.Newtypes
    Database.PostgreSQL.Simple.Notification
    Database.PostgreSQL.Simple.Ok Database.PostgreSQL.Simple.Range
    Database.PostgreSQL.Simple.SqlQQ Database.PostgreSQL.Simple.Time
    Database.PostgreSQL.Simple.Time.Internal
    Database.PostgreSQL.Simple.ToField Database.PostgreSQL.Simple.ToRow
    Database.PostgreSQL.Simple.Transaction
    Database.PostgreSQL.Simple.TypeInfo
    Database.PostgreSQL.Simple.TypeInfo.Macro
    Database.PostgreSQL.Simple.TypeInfo.Static
    Database.PostgreSQL.Simple.Types Database.PostgreSQL.Simple.Vector
    Database.PostgreSQL.Simple.Vector.Unboxed

hidden-modules:
    Database.PostgreSQL.Simple.Compat
    Database.PostgreSQL.Simple.HStore.Implementation
    Database.PostgreSQL.Simple.Internal.PQResultUtils
    Database.PostgreSQL.Simple.Time.Implementation
    Database.PostgreSQL.Simple.Time.Internal.Parser
    Database.PostgreSQL.Simple.Time.Internal.Printer
    Database.PostgreSQL.Simple.TypeInfo.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/postgresql-simple-0.6.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/postgresql-simple-0.6.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-postgresql-simple
hs-libraries:         HSpostgresql-simple-0.6.5-1bJK5KSvjQ6FaX8TDJVqT3
depends:
    Only-0.1-DiaFlOQSZ1l8JCg8TmCabZ
    aeson-2.1.2.1-6EBV889cSS7AqjoZtYoje8
    attoparsec-0.14.4-HEPxPDNq5mJKRZZEtIXOMd base-4.16.4.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-BBCkGXkqh3nGRz3m4HFNUT
    containers-0.6.5.1 hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    postgresql-libpq-0.9.4.3-KEIdZq7PBXuLHl7WTAWu9q
    scientific-0.3.7.0-KUJ0yQBDqbB75MLhDe7uzc template-haskell-2.18.0.0
    text-1.2.5.0 time-compat-1.9.6.1-4LKUUS0AewnA698ITHrhN1
    transformers-0.5.6.2 uuid-types-1.0.5.1-DzR0IgzRElQ1K705w84ENs
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:
    /usr/share/doc/haskell-postgresql-simple/html/postgresql-simple.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-simple/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
